@@ -3,7 +3,7 @@
 module TPDB.CPF.Proof.Read where
 
 import TPDB.CPF.Proof.Type as Type
-import TPDB.Data
+import TPDB.Data hiding (Type (..))
 
 {-
 import Text.XML.HXT.Arrow.XmlArrow
@@ -65,10 +65,17 @@ fromDoc = element1 "certificationProblem" >=> \ c ->
   ( CertificationProblem
      <$> (c $/ element "cpfVersion" &/ content )
      <*> (c $/ element "input" &/ getInput )
+     <*> (c $/ element "property" &/ getProperty )
+     <*> (c $/ element "answer" &/ getAnswer )
      <*> (c $/ element "proof" &/ getProof)
      <*> (c $/ element "origin" >=> return [ignoredOrigin] )
   )
 
+getProperty = (element "termination" >> return [ Termination])
+
+getAnswer = (element "no" >> return [No])
+       <>   (element "yes" >> return [Yes])
+
 getInput =  getTerminationInput
    <> getComplexityInput
    <> getACTerminationInput
@@ -86,7 +93,6 @@ getACTerminationInput = element "acRewriteSystem" >=> \ c -> do
       , csymbols = cs
       }
 
-
 getComplexityInput = element "input" >=> \ c -> do
     trsI <- c $/ element "complexityInput" &/ element "trsInput" &/ getTrsInput
     cm <- c $/ getComplexityMeasure 
